// coreServices.ts
import { getCompositeStore } from './compositeStores';
import { interpret, Machine } from 'xstate';

export const coreServices = {
    updateComposite: (mappings: Record<string, string>) => {
        for (const [mappingString, value] of Object.entries(mappings)) {
            const [storeID, key] = mappingString.replace('@', '').split(':');
            const store = getCompositeStore(storeID);
            store.update(storeData => {
                storeData[key] = value;
                return storeData;
            });
        }
    },
    subscribeComposite: (mappingString: string) => {
        const [storeID] = mappingString.replace('@', '').split(':');
        const store = getCompositeStore(storeID);
        return store;
    },
    testAlert: () => {
        alert("core service alert")
    },
    machine: {
        service: null,
        send: (event) => coreServices.machine.service.send(event),
        initialize: (machineDefinition, store) => {
            const machine = Machine(machineDefinition);
            coreServices.machine.service = interpret(machine).onTransition((state) => {
                store.update(storeValue => ({ ...storeValue, machine: { state: state.value } }));
            });
            coreServices.machine.service.start();
        }
    }
};
